# `dessicate`
> This project was started to house functions Mike uses a lot so he doesn't have to writ them over and over again. I hope you find some of them useful!


This file will become your README and also the index of your documentation.

## Install

`pip install dessiccate`

## How to use
